@@ -10,48 +10,54 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.04';
-$DATE = '2003/08/04';
+$VERSION = '0.05';
+$DATE = '2004/05/11';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    'MANIFEST' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
-    'README' => [qw(0.04 2003/08/04), 'generated, replaces 0.03'],
-    'lib/ExtUtils/SVDmaker.pm' => [qw(1.06 2003/08/04), 'revised 1.05'],
-    'bin/vmake.pl' => [qw(1.04 2003/08/04), 'revised 1.03'],
-    't/ExtUtils/SVDmaker/SVDmaker.d' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    't/ExtUtils/SVDmaker/SVDmaker.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    't/ExtUtils/SVDmaker/SVDmaker.t' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    't/ExtUtils/SVDmaker/lib/SVDtest1.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/lib/SVDtest1.t' => [qw(0.02 2003/08/04), 'new'],
-    'tlib/Test/Tech.pm' => [qw(1.12 2003/08/04), 'unchanged'],
-    'tlib/File/SmartNL.pm,' => [qw(1.12 2003/08/04), 'revised 1.11'],
-    't/ExtUtils/SVDmaker/expected/Makefile' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/Makefile2.PL' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/Makefile3.PL' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/MANIFEST2' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/module0A.pm' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/module0B.pm' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/module2.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/README2' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/README3' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    't/ExtUtils/SVDmaker/expected/SVDmaker0.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest-0.01.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest0A.pm' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/SVDtest0A.t' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/SVDtest0B.pm' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/SVDtest0B.t' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest2.pm' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest2.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest2.t' => [qw(0.04 2003/08/04), 'new'],
-    't/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html' => [qw(0.03 2003/08/04), 'revised 0.02'],
-    't/ExtUtils/SVDmaker/expected/SVDtest3.pm' => [qw(0.04 2003/08/04), 'revised 0.03'],
-    't/ExtUtils/SVDmaker/expected/SVDtest3.ppd' => [qw(0.03 2003/08/04), 'revised 0.02'],
+    'lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    'MANIFEST' => [qw(0.05 2004/05/11), 'generated, replaces 0.04'],
+    'Makefile.PL' => [qw(0.05 2004/05/11), 'generated, replaces 0.04'],
+    'README' => [qw(0.05 2004/05/11), 'generated, replaces 0.04'],
+    'lib/ExtUtils/SVDmaker.pm' => [qw(1.07 2004/05/11), 'revised 1.06'],
+    't/ExtUtils/SVDmaker/SVDmaker.d' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/SVDmaker.pm' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/SVDmaker.t' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/lib/SVDtest1.pm' => [qw(0.03 2004/05/11), 'revised 0.02'],
+    't/ExtUtils/SVDmaker/vmake.pl' => [qw(1.04 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/Test/Tech.pm' => [qw(1.24 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/Data/Secs2.pm' => [qw(1.22 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/Data/SecsPack.pm' => [qw(0.07 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/Data/Startup.pm' => [qw(0.06 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/expected/Makefile' => [qw(0.04 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/Makefile2.PL' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/Makefile3.PL' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/MANIFEST2' => [qw(0.04 2004/05/11), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/module0A.pm' => [qw(0.04 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/module0B.pm' => [qw(0.04 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/module2.pm' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/README2' => [qw(0.04 2004/05/11), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/README3' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDmaker0.pm' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest-0.01.html' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest.ppd' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0A.pm' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0A.t' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0B.pm' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDtest0B.t' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.pm' => [qw(0.04 2004/05/11), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.ppd' => [qw(0.04 2004/05/11), 'revised 0.03'],
+    't/ExtUtils/SVDmaker/expected/SVDtest2.t' => [qw(0.04 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3.pm' => [qw(0.05 2004/05/11), 'revised 0.04'],
+    't/ExtUtils/SVDmaker/expected/SVDtest3.ppd' => [qw(0.03 2003/08/04), 'unchanged'],
+    't/ExtUtils/SVDmaker/expected/Test/Tech.pm' => [qw(0.05 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/expected/Data/Secs2.pm' => [qw(0.05 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/expected/Data/SecsPack.pm' => [qw(0.05 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/expected/Data/Startup.pm' => [qw(0.05 2004/05/11), 'new'],
+    't/ExtUtils/SVDmaker/expected/File/Package.pm' => [qw(0.05 2004/05/11), 'new'],
 
 );
 
@@ -70,25 +76,29 @@ use vars qw(%INVENTORY);
 
 
 
+=head1 NAME
+
+ ExtUtil::SVDmaker - Automate creating CPAN distributions
+
 =head1 Title Page
 
  Software Version Description
 
  for
 
- ExtUtil::SVDmaker - Packaging modules for CPAN and Software Version Description (SVD) Automation
+ ExtUtil::SVDmaker - Automate creating CPAN distributions
 
- Revision: C
+ Revision: D
 
- Version: 0.04
+ Version: 0.05
 
- Date: 2003/08/04
+ Date: 2004/05/11
 
  Prepared for: General Public 
 
- Prepared by:  SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>
+ Prepared by:  SoftwareDiamonds.com E<lt> support@SoftwareDiamonds.com E<gt>
 
- Copyright: copyright  2003 Software Diamonds
+ Copyright: copyright 2003 Software Diamonds
 
  Classification: NONE
 
@@ -176,29 +186,9 @@ a text database in the Data::Port::FileTYpe::FormDB format.
 
 =back
 
-The dependency of the program modules in the US DOD STD2167A bundle is as follows:
-
- File::TestPath File::Package File::SmartNL
-   Text::Scrub
-     Test::Tech
-
-        DataPort::FileType::FormDB DataPort::DataFile DataPort::Maker Text::Replace
-        Text::Column File::PM2File File::Data File::AnySpec File::SubPM
-
-            Test::STDmaker ExtUtils::SVDmaker
-
-The top level modules that establish the functional interface of
-interest to the end user are the 
-L<Test::STDmaker|Test::STDmaker> and the 
-L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> modules.
-The rest of the modules in the above dependency tree are design
-modules for the US DOD STD2167A bundle. 
-They are broken out as separate modules because they may be
-of use outside of the US DOD STD2167A bundle.
-
 =head2 1.3 Document overview.
 
-This document releases ExtUtils::SVDmaker version 0.04
+This document releases ExtUtils::SVDmaker version 0.05
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -211,12 +201,14 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-This document releases the file found
-at the following repository(s):
+This document releases the file 
 
-   http://www.softwarediamonds/packages/ExtUtils-SVDmaker-0.04
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/ExtUtils-SVDmaker-0.04
+ ExtUtils-SVDmaker-0.05.tar.gz
 
+found at the following repository(s):
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
 Restrictions regarding duplication and license provisions
 are as follows:
@@ -225,7 +217,7 @@ are as follows:
 
 =item Copyright.
 
-copyright  2003 Software Diamonds
+copyright 2003 Software Diamonds
 
 =item Copyright holder contact.
 
@@ -264,6 +256,20 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 =back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -292,42 +298,48 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm                       0.04    2003/08/04 revised 0.03
- MANIFEST                                                     0.04    2003/08/04 generated, replaces 0.03
- Makefile.PL                                                  0.04    2003/08/04 generated, replaces 0.03
- README                                                       0.04    2003/08/04 generated, replaces 0.03
- lib/ExtUtils/SVDmaker.pm                                     1.06    2003/08/04 revised 1.05
- bin/vmake.pl                                                 1.04    2003/08/04 revised 1.03
- t/ExtUtils/SVDmaker/SVDmaker.d                               0.04    2003/08/04 revised 0.03
- t/ExtUtils/SVDmaker/SVDmaker.pm                              0.04    2003/08/04 revised 0.03
- t/ExtUtils/SVDmaker/SVDmaker.t                               0.04    2003/08/04 revised 0.03
- t/ExtUtils/SVDmaker/lib/SVDtest1.pm                          0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/lib/SVDtest1.t                           0.02    2003/08/04 new
- tlib/Test/Tech.pm                                            1.12    2003/08/04 unchanged
- tlib/File/SmartNL.pm,                                        1.12    2003/08/04 revised 1.11
- t/ExtUtils/SVDmaker/expected/Makefile                        0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/Makefile2.PL                    0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/Makefile3.PL                    0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/MANIFEST2                       0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/module0A.pm                     0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/module0B.pm                     0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/module2.pm                      0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/README2                         0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/README3                         0.04    2003/08/04 revised 0.03
- t/ExtUtils/SVDmaker/expected/SVDmaker0.pm                    0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest-0.01.html               0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest.ppd                     0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest0A.pm                    0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/SVDtest0A.t                     0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/SVDtest0B.pm                    0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/SVDtest0B.t                     0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html              0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest2.pm                     0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest2.ppd                    0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest2.t                      0.04    2003/08/04 new
- t/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html              0.03    2003/08/04 revised 0.02
- t/ExtUtils/SVDmaker/expected/SVDtest3.pm                     0.04    2003/08/04 revised 0.03
- t/ExtUtils/SVDmaker/expected/SVDtest3.ppd                    0.03    2003/08/04 revised 0.02
+ lib/Docs/Site_SVD/ExtUtils_SVDmaker.pm                       0.05    2004/05/11 revised 0.04
+ MANIFEST                                                     0.05    2004/05/11 generated, replaces 0.04
+ Makefile.PL                                                  0.05    2004/05/11 generated, replaces 0.04
+ README                                                       0.05    2004/05/11 generated, replaces 0.04
+ lib/ExtUtils/SVDmaker.pm                                     1.07    2004/05/11 revised 1.06
+ t/ExtUtils/SVDmaker/SVDmaker.d                               0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/SVDmaker.pm                              0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/SVDmaker.t                               0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/lib/SVDtest1.pm                          0.03    2004/05/11 revised 0.02
+ t/ExtUtils/SVDmaker/vmake.pl                                 1.04    2004/05/11 new
+ t/ExtUtils/SVDmaker/Test/Tech.pm                             1.24    2004/05/11 new
+ t/ExtUtils/SVDmaker/Data/Secs2.pm                            1.22    2004/05/11 new
+ t/ExtUtils/SVDmaker/Data/SecsPack.pm                         0.07    2004/05/11 new
+ t/ExtUtils/SVDmaker/Data/Startup.pm                          0.06    2004/05/11 new
+ t/ExtUtils/SVDmaker/expected/Makefile                        0.04    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/Makefile2.PL                    0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/Makefile3.PL                    0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/MANIFEST2                       0.04    2004/05/11 revised 0.03
+ t/ExtUtils/SVDmaker/expected/module0A.pm                     0.04    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/module0B.pm                     0.04    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/module2.pm                      0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/README2                         0.04    2004/05/11 revised 0.03
+ t/ExtUtils/SVDmaker/expected/README3                         0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDmaker0.pm                    0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest-0.01.html               0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest.ppd                     0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest0A.pm                    0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDtest0A.t                     0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDtest0B.pm                    0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDtest0B.t                     0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDtest2-0.01.html              0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest2.pm                     0.04    2004/05/11 revised 0.03
+ t/ExtUtils/SVDmaker/expected/SVDtest2.ppd                    0.04    2004/05/11 revised 0.03
+ t/ExtUtils/SVDmaker/expected/SVDtest2.t                      0.04    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest3-0.02.html              0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/SVDtest3.pm                     0.05    2004/05/11 revised 0.04
+ t/ExtUtils/SVDmaker/expected/SVDtest3.ppd                    0.03    2003/08/04 unchanged
+ t/ExtUtils/SVDmaker/expected/Test/Tech.pm                    0.05    2004/05/11 new
+ t/ExtUtils/SVDmaker/expected/Data/Secs2.pm                   0.05    2004/05/11 new
+ t/ExtUtils/SVDmaker/expected/Data/SecsPack.pm                0.05    2004/05/11 new
+ t/ExtUtils/SVDmaker/expected/Data/Startup.pm                 0.05    2004/05/11 new
+ t/ExtUtils/SVDmaker/expected/File/Package.pm                 0.05    2004/05/11 new
 
 
 =head2 3.3 Changes
@@ -377,6 +389,29 @@ Hopefully dealing with the Text '\n' problem by isolating and testing
 these functions separately. They also have high probability of being
 useful outside this module.
 
+=item ExtUtils::SVDmaker-0.05
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/ExtUtils, the same directory as the test script
+and deleting the test library C<File::TestPath> program module.
+
+Added addition code to the test target to isolate the program module
+under test. Before the test, the @INC directories are stipped back
+to the first one contain Perl. This is to isolate the test to only
+the virgin Perl distribution program modules. The test target then
+creates a require directory under the same directory as the test script
+and copies over all prequesite program modules to this directory.
+After the test target performs the test it restores @INC and removes
+the require directory tree.
+
+Hopefully this will eliminate many time consuming distributions failure
+due to using program modules that that are not part of the distributions.
+
+SWitch from C<DataPort::Maker> to C<File::Maker>. Eliminated the use
+of C<File::Data> and C<File::TestPath>
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -401,25 +436,59 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-Follow the general Perl software installation procedure
-to install the files contained in this distribution file.
+To installed the release package, use the CPAN module
+pr PPM module in the Perl release
+or the INSTALL.PL script at the following web site:
 
-The distribution name and version are as follows:
+ http://packages.SoftwareDiamonds.com
 
- distribution name: ExtUtils-SVDmaker
- version          : 0.04
+Follow the instructions for the the chosen installation software.
+
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
+
+Right click on 'ExtUtils-SVDmaker-0.05.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ExtUtils-SVDmaker-0.05.tar.gz
+ tar -xf ExtUtils-SVDmaker-0.05.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
+
+VERY IMPORTANT:
+
+The distribution package contains the cover
+C<vmake.pl> perl command script.
+Manually copy this into the execution path
+in order to use C<SVDmaker> from the
+command line. Rename it if there is a
+name conflict or just do not like the name.
 
 =item Prerequistes.
 
- 'DataPort::FileType::FormDB' => '0.03',
- 'DataPort::Maker' => '1.04',
- 'DataPort::DataFile' => '0.04',
- 'Text::Scrub' => '0',
+ 'Archive::TarGzip' => '0',
+ 'File::AnySpec' => '1.13',
+ 'File::Maker' => '0.03',
+ 'File::Package' => '1.16',
+ 'File::SmartNL' => '1.14',
+ 'File::Where' => '0',
  'Text::Replace' => '0',
  'Text::Column' => '0',
- 'File::AnySpec' => '0',
- 'File::Package' => '0',
- 'File::Data' => '0',
+ 'Text::Scrub' => '1.13',
+ 'Tie::Form' => '0.01',
+ 'Tie::Layers' => '0.04',
 
 
 =item Security, privacy, or safety precautions.
@@ -511,49 +580,25 @@ as follows:
 
 =over 4
 
-=item L<Test::STDmaker|Test::STDmaker>
-
 =item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
 
-=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
-
-=item L<DataPort::DataFile|DataPort::DataFile>
+=item L<Test::STDmaker|Test::STDmaker>
 
 =item L<Test::Tech|Test::Tech>
 
 =item L<Test|Test>
 
-=item L<Data::Dumper|Data::Dumper>
+=item L<File::Maker|File::Maker>
 
-=item L<Test::STD::Scrub|Test::STD::Scrub>
+=item L<Tie::Form|Tie::Form>
 
-=item L<Test::STD::STDutil|Test::STD::STDutil>
+=item L<Tie::Layers|Tie::Layers>
 
-=item L<File::FileUtil|File::FileUtil>
+=item L<Text::Column|Text::Column>
 
-=back
+=item L<Text::Replace|Text::Replace>
 
-The design modules for L<Test::STDmaker|Test::STDmaker>
-have no other conceivable use then to support the
-L<Test::STDmaker|Test::STDmaker> functional interface. 
-The  L<Test::STDmaker|Test::STDmaker>
-design module are as follows:
-
-=over 4
-
-=item L<Test::STD::Check|Test::STD::Check>
-
-=item L<Test::STD::FileGen|Test::STD::FileGen>
-
-=item L<Test::STD::STD2167|Test::STD::STD2167>
-
-=item L<Test::STD::STDgen|Test::STD::STDgen>
-
-=item L<Test::STDtype::Demo|Test::STDtype::Demo>
-
-=item L<Test::STDtype::STD|Test::STDtype::STD>
-
-=item L<Test::STDtype::Verify|Test::STDtype::Verify>
+=item L<Text::Scrub|Text::Scrub>
 
 =back
 
@@ -625,20 +670,7 @@ US DOD 2167A automation are as follows:
 =back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -647,23 +679,21 @@ US DOD 2167A automation are as follows:
 __DATA__
 
 DISTNAME: ExtUtils-SVDmaker^
-REPOSITORY_DIR: packages^
-
-VERSION : 0.04^
+VERSION : 0.05^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.03^
-REVISION: C^
+PREVIOUS_RELEASE: 0.04^
+REVISION: D^
 
-AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
+AUTHOR  : SoftwareDiamonds.com E<lt> support@SoftwareDiamonds.com E<gt>^
 ABSTRACT: 
-Software to generate Software Version Description (SVD) program modules and 
-package modules for CPAN.
+Generate Software Version Description (SVD) program modules and 
+distribution files for CPAN.
 ^
 
-TITLE: ExtUtil::SVDmaker - Packaging modules for CPAN and Software Version Description (SVD) Automation^
+TITLE: ExtUtil::SVDmaker - Automate creating CPAN distributions^
 END_USER: General Public^
-COPYRIGHT: copyright  2003 Software Diamonds^
+COPYRIGHT: copyright 2003 Software Diamonds^
 CLASSIFICATION: NONE^
 
 CSS: help.css^
@@ -672,10 +702,11 @@ SVD_FSPEC: Unix^
 
 COMPRESS: gzip^
 COMPRESS_SUFFIX: gz^
+REPOSITORY_DIR: packages^
 
 REPOSITORY: 
   http://www.softwarediamonds/packages/
-  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 ^
 
 CHANGE2CURRENT:  ^
@@ -683,31 +714,39 @@ RESTRUCTURE:  ^
 
 AUTO_REVISE:
 lib/ExtUtils/SVDmaker.pm
-bin/vmake.pl
 t/ExtUtils/SVDmaker/*
 t/ExtUtils/SVDmaker/lib/*
-t/ExtUtils/SVDmaker/t/*
-lib/Test/Tech.pm => tlib/Test/Tech.pm
-lib/File/SmartNL.pm => tlib/File/SmartNL.pm,
+bin/vmake.pl => t/ExtUtils/SVDmaker/vmake.pl
+lib/Test/Tech.pm => t/ExtUtils/SVDmaker/Test/Tech.pm
+lib/Data/Secs2.pm => t/ExtUtils/SVDmaker/Data/Secs2.pm
+lib/Data/SecsPack.pm => t/ExtUtils/SVDmaker/Data/SecsPack.pm
+lib/Data/Startup.pm => t/ExtUtils/SVDmaker/Data/Startup.pm
 ^
 
-REPLACE: t/ExtUtils/SVDmaker/expected/* ^
-
+REPLACE: 
+t/ExtUtils/SVDmaker/expected/*
+t/ExtUtils/SVDmaker/expected/Test/*
+t/ExtUtils/SVDmaker/expected/Data/*
+t/ExtUtils/SVDmaker/expected/File/*
+^
 
 PREREQ_PM:
-'DataPort::FileType::FormDB' => '0.03',
-'DataPort::Maker' => '1.04',
-'DataPort::DataFile' => '0.04',
-'Text::Scrub' => '0',
+'Archive::TarGzip' => '0',
+'File::AnySpec' => '1.13',
+'File::Maker' => '0.03',
+'File::Package' => '1.16',
+'File::SmartNL' => '1.14',
+'File::Where' => '0',
 'Text::Replace' => '0',
 'Text::Column' => '0',
-'File::AnySpec' => '0',
-'File::Package' => '0',
-'File::Data' => '0',
+'Text::Scrub' => '1.13',
+'Tie::Form' => '0.01',
+'Tie::Layers' => '0.04',
 ^
 
+README_PODS: lib/ExtUtils/SVDmaker.pm^
 TESTS: t/ExtUtils/SVDmaker/SVDmaker.t^
-EXE_FILES: bin/vmake.pl^
+EXE_FILES: ^
 
 CHANGES:
 Changes are as follows:
@@ -755,6 +794,29 @@ Hopefully dealing with the Text '\n' problem by isolating and testing
 these functions separately. They also have high probability of being
 useful outside this module.
 
+\=item ExtUtils::SVDmaker-0.05
+
+The lastest build of Test::STDmaker expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/ExtUtils, the same directory as the test script
+and deleting the test library C<File::TestPath> program module.
+
+Added addition code to the test target to isolate the program module
+under test. Before the test, the @INC directories are stipped back
+to the first one contain Perl. This is to isolate the test to only
+the virgin Perl distribution program modules. The test target then
+creates a require directory under the same directory as the test script
+and copies over all prequesite program modules to this directory.
+After the test target performs the test it restores @INC and removes
+the require directory tree.
+
+Hopefully this will eliminate many time consuming distributions failure
+due to using program modules that that are not part of the distributions.
+
+SWitch from C<DataPort::Maker> to C<File::Maker>. Eliminated the use
+of C<File::Data> and C<File::TestPath>
+
 \=back
 ^
 
@@ -829,25 +891,6 @@ a text database in the Data::Port::FileTYpe::FormDB format.
 
 \=back
 
-The dependency of the program modules in the US DOD STD2167A bundle is as follows:
-
- File::TestPath File::Package File::SmartNL
-   Text::Scrub
-     Test::Tech
-
-        DataPort::FileType::FormDB DataPort::DataFile DataPort::Maker Text::Replace
-        Text::Column File::PM2File File::Data File::AnySpec File::SubPM
-
-            Test::STDmaker ExtUtils::SVDmaker
-
-The top level modules that establish the functional interface of
-interest to the end user are the 
-L<Test::STDmaker|Test::STDmaker> and the 
-L<ExtUtils::SVDmaker|ExtUtils::SVDmaker> modules.
-The rest of the modules in the above dependency tree are design
-modules for the US DOD STD2167A bundle. 
-They are broken out as separate modules because they may be
-of use outside of the US DOD STD2167A bundle.
 ^
 
 DOCUMENT_OVERVIEW:
@@ -889,6 +932,20 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+\=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 \=back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -911,13 +968,45 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-Follow the general Perl software installation procedure
-to install the files contained in this distribution file.
+To installed the release package, use the CPAN module
+pr PPM module in the Perl release
+or the INSTALL.PL script at the following web site:
 
-The distribution name and version are as follows:
+ http://packages.SoftwareDiamonds.com
+
+Follow the instructions for the the chosen installation software.
+
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
+
+${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
+
+VERY IMPORTANT:
+
+The distribution package contains the cover
+C<vmake.pl> perl command script.
+Manually copy this into the execution path
+in order to use C<SVDmaker> from the
+command line. Rename it if there is a
+name conflict or just do not like the name.
 
- distribution name: ${DISTNAME}
- version          : ${VERSION}
 ^
 
 
@@ -993,49 +1082,25 @@ as follows:
 
 \=over 4
 
-\=item L<Test::STDmaker|Test::STDmaker>
-
 \=item L<ExtUtils::SVDmaker|ExtUtils::SVDmaker>
 
-\=item L<DataPort::FileType::FormDB|DataPort::FileType::FormDB>
-
-\=item L<DataPort::DataFile|DataPort::DataFile>
+\=item L<Test::STDmaker|Test::STDmaker>
 
 \=item L<Test::Tech|Test::Tech>
 
 \=item L<Test|Test>
 
-\=item L<Data::Dumper|Data::Dumper>
+\=item L<File::Maker|File::Maker>
 
-\=item L<Test::STD::Scrub|Test::STD::Scrub>
+\=item L<Tie::Form|Tie::Form>
 
-\=item L<Test::STD::STDutil|Test::STD::STDutil>
+\=item L<Tie::Layers|Tie::Layers>
 
-\=item L<File::FileUtil|File::FileUtil>
+\=item L<Text::Column|Text::Column>
 
-\=back
+\=item L<Text::Replace|Text::Replace>
 
-The design modules for L<Test::STDmaker|Test::STDmaker>
-have no other conceivable use then to support the
-L<Test::STDmaker|Test::STDmaker> functional interface. 
-The  L<Test::STDmaker|Test::STDmaker>
-design module are as follows:
-
-\=over 4
-
-\=item L<Test::STD::Check|Test::STD::Check>
-
-\=item L<Test::STD::FileGen|Test::STD::FileGen>
-
-\=item L<Test::STD::STD2167|Test::STD::STD2167>
-
-\=item L<Test::STD::STDgen|Test::STD::STDgen>
-
-\=item L<Test::STDtype::Demo|Test::STDtype::Demo>
-
-\=item L<Test::STDtype::STD|Test::STDtype::STD>
-
-\=item L<Test::STDtype::Verify|Test::STDtype::Verify>
+\=item L<Text::Scrub|Text::Scrub>
 
 \=back
 
@@ -1107,22 +1172,22 @@ US DOD 2167A automation are as follows:
 \=back
 
 ^
+
+
 HTML:
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 ^
+
 ~-~
 
 
+
+
+
+
+
+
+
+
+
+
